#version 330

in vec3 worldNormal;
in vec3 worldPos;

uniform vec3 lightColor;
uniform float ambientIntensity;
uniform vec3 lightDirection;
uniform float diffuseIntensity;
uniform vec3 viewWorldPos;
uniform float specularIntensity;
uniform float specularPower;

out vec4 color;

void main(){
	vec3 nNormal = normalize(worldNormal);
	vec4 ambientColor = vec4(lightColor, 1.0f) * ambientIntensity;
	float diffuseFactor = dot(nNormal, -lightDirection);

	vec4 diffuseColor = vec4(0.0f, 0.0f, 0.0f, 0.0f);
	vec4 specularColor = vec4(0.0f, 0.0f, 0.0f, 0.0f);

	if(diffuseFactor > 0.0f){
		diffuseColor = vec4(lightColor, 1.0f) * diffuseIntensity * diffuseFactor;

		vec3 toViewer = normalize(viewWorldPos - worldPos);
		vec3 reflected = normalize(reflect(lightDirection, nNormal));
		float specularFactor = pow(dot(toViewer, reflected), specularPower);
		if(specularFactor > 0){
			specularColor = vec4(lightColor, 1.0f) * specularIntensity * specularFactor;
		}

	}

	color = vec4(0.0f, 0.0f, 1.0f, 1.0f) * (ambientColor + diffuseColor + specularColor);
}